@@ -9,12 +9,17 @@ class Metric(abc.ABC):
 
     _type: Optional[type] = None
 
-    def __init__(self, name: Optional[str] = None):
+    def __init__(self, name: Optional[str] = None, help_text: str = "", **kwargs):
         """
         Name could be supplied later on if the dimension is declared in HCube class specification
-        for example
+        for example.
+
+        kwargs are passed to the backend and may be used to pass special arguments to individual
+        backends
         """
         self.name: Optional[str] = name
+        self.help_text = help_text
+        self.kwargs = kwargs
 
     def to_python(self, value: Any):
         """
@@ -30,12 +35,19 @@ class IntMetric(Metric):
 
     _type = int
 
-    def __init__(self, name: Optional[str] = None, signed: bool = True, bits: int = 32):
+    def __init__(
+        self,
+        name: Optional[str] = None,
+        signed: bool = True,
+        bits: int = 32,
+        help_text: str = "",
+        **kwargs,
+    ):
         """
         Backends are not required to use the `signed` and `bits` information. They are there just
         as hints to backends which support it.
         """
-        super().__init__(name)
+        super().__init__(name, help_text=help_text, **kwargs)
         self.signed = signed
         self.bits = bits
 
