@@ -8,9 +8,14 @@ from hcube.api.models.filters import (
     ComparisonType,
     EqualityFilter,
     Filter,
+    FilterCombinator,
     IsNullFilter,
     ListFilter,
     NegativeListFilter,
+    OverlapFilter,
+    SubstringFilter,
+    SubstringMultiValueFilter,
+    Wrapper,
 )
 from hcube.api.models.metrics import Metric
 from hcube.api.models.ordering import OrderDirection, OrderSpec
@@ -26,6 +31,7 @@ class CubeQuery:
         "in": ListFilter,
         "isnull": IsNullFilter,
         "not_in": NegativeListFilter,
+        "overlap": OverlapFilter,
     }
 
     def __init__(self, cube: Type["Cube"]):  # noqa - cannot import Cube - circular import
@@ -39,7 +45,12 @@ class CubeQuery:
 
     def filter(self, *fltrs: Filter, **named_filters: Any) -> "CubeQuery":
         for fltr in fltrs:
-            self._check_own_dimension(fltr.dimension)
+            if isinstance(fltr, FilterCombinator):
+                self._check_combinator(fltr)
+            elif isinstance(fltr, Wrapper):
+                fltr = self._resolve_wrapper(fltr)
+            else:
+                self._check_own_dimension(fltr.dimension)
             self.filters.append(fltr)
         for spec, value in named_filters.items():
             self.filters.append(self._resolve_shorthand(spec, value))
@@ -141,7 +152,7 @@ class CubeQuery:
             transform.dimension = self._resolve_dim(transform.dimension)
         return self
 
-    def _resolve_shorthand(self, spec: str, value: Any):
+    def _resolve_shorthand(self, spec: str, value: Any) -> Filter:
         parts = spec.split("__")
         if len(parts) == 1:
             return EqualityFilter(dimension=self._resolve_dim(parts[0]), value=value)
@@ -153,10 +164,22 @@ class CubeQuery:
             return fltr_cls(self._resolve_dim(dim_name), value)
         if shorthand in ("gt", "gte", "lt", "lte"):
             return ComparisonFilter(
-                dimension=self.cube.dimension_by_name(dim_name),
+                dimension=self._resolve_dim(dim_name),
                 comparison=ComparisonType[shorthand.upper()],
                 value=value,
             )
+        if shorthand in ("contains", "icontains"):
+            return SubstringFilter(
+                dimension=self._resolve_dim(dim_name),
+                value=value,
+                case_sensitive=shorthand == "contains",
+            )
+        if shorthand in ("mcontains", "imcontains"):
+            return SubstringMultiValueFilter(
+                dimension=self._resolve_dim(dim_name),
+                values=value,
+                case_sensitive=shorthand == "mcontains",
+            )
         raise ValueError(f"unsupported filter `{shorthand}`")
 
     def _resolve_dim(self, dim: Union[str, Dimension]) -> Union[Dimension, Transform]:
@@ -194,6 +217,22 @@ class CubeQuery:
             raise ConsistencyError(f'Metric "{metric}" is not associated with cube: {self.cube}')
         return metric
 
+    def _check_combinator(self, combinator: FilterCombinator):
+        new_filters = []
+        for fltr in combinator.filters:
+            if isinstance(fltr, FilterCombinator):
+                self._check_combinator(fltr)
+                new_filters.append(fltr)
+            elif isinstance(fltr, Wrapper):
+                new_filters.append(self._resolve_wrapper(fltr))
+            else:
+                self._check_own_dimension(fltr.dimension)
+                new_filters.append(fltr)
+        combinator.filters = new_filters
+
+    def _resolve_wrapper(self, wrapper: Wrapper) -> Filter:
+        return self._resolve_shorthand(wrapper.key, wrapper.value)
+
     def __getitem__(self, key):
         if isinstance(key, slice):
             if key.start:
