@@ -1,4 +1,5 @@
 import logging
+import threading
 from collections import Counter, namedtuple
 from dataclasses import dataclass, field, fields
 from time import monotonic
@@ -109,7 +110,7 @@ class ClickhouseCubeBackend(CubeBackend):
         self.client_attrs = client_attrs
         self.pool = ChPool(database=database, **client_attrs)
         self._table_exists = {}
-        self._query_counts = Counter()
+        self._query_counts = {}
 
     def initialize_storage(self, cube: Type[Cube]) -> None:
         self._create_table(cube)
@@ -140,7 +141,7 @@ class ClickhouseCubeBackend(CubeBackend):
                 f"INSERT INTO {self.database}.{self.cube_to_table_name(cube)} VALUES ",
                 data,
             )
-            self._query_counts[cube.__name__] += 1
+            self._count_query(cube)
 
     def get_records(
         self,
@@ -167,7 +168,7 @@ class ClickhouseCubeBackend(CubeBackend):
         with self.pool.get_client() as client:
             output = client.execute(text, params)
             logger.debug(f"Query time: {monotonic() - start: .3f} s")
-            self._query_counts[query.cube.__name__] += 1
+            self._count_query(query.cube)
             for rec in output:
                 yield result(*rec)
 
@@ -241,7 +242,7 @@ class ClickhouseCubeBackend(CubeBackend):
         start = monotonic()
         with self.pool.get_client() as client:
             client.execute(whole_text, params)
-            self._query_counts[query.cube.__name__] += 1
+            self._count_query(query.cube)
             logger.debug(f"Query time: {monotonic() - start: .3f} s")
 
     def delete_records_hard(self, query: CubeQuery) -> None:
@@ -274,7 +275,7 @@ class ClickhouseCubeBackend(CubeBackend):
         start = monotonic()
         with self.pool.get_client() as client:
             client.execute(text, params)
-            self._query_counts[query.cube.__name__] += 1
+            self._count_query(query.cube)
             logger.debug(f"Query time: {monotonic() - start: .3f} s")
 
     @classmethod
@@ -532,7 +533,7 @@ class ClickhouseCubeBackend(CubeBackend):
         )
         logger.debug(command)
         with self.pool.get_client() as client:
-            self._query_counts[cube.__name__] += 1
+            self._count_query(cube)
             client.execute(command)
 
     def _ch_type(self, dimension: Union[Dimension, Metric]) -> str:
@@ -586,7 +587,7 @@ class ClickhouseCubeBackend(CubeBackend):
         )
         logger.debug(command)
         with self.pool.get_client() as client:
-            self._query_counts[cube.__name__] += 1
+            self._count_query(cube)
             client.execute(command)
 
     def _create_projection(
@@ -609,12 +610,12 @@ class ClickhouseCubeBackend(CubeBackend):
         logger.debug(command)
         with self.pool.get_client() as client:
             client.execute(command)
-            self._query_counts[cube.__name__] += 1
+            self._count_query(cube)
             if populate:
                 client.execute(
                     f"ALTER TABLE {self.database}.{table_name} MATERIALIZE PROJECTION {view_name}"
                 )
-                self._query_counts[cube.__name__] += 1
+                self._count_query(cube)
 
     def _create_dictionaries(self, cube: Type[Cube]):
         meta = self.get_table_meta(cube)
@@ -625,25 +626,25 @@ class ClickhouseCubeBackend(CubeBackend):
                     f"SELECT comment FROM system.dictionaries "
                     f"WHERE database = '{self.database}' AND name = '{dict_def.name}'"
                 )
-                self._query_counts[cube.__name__] += 1
+                self._count_query(cube)
                 if out:
                     if out[0][0] != f"blake2:{dict_def.checksum}":
                         logger.info(
                             'Dictionary "%s" definition has changed, recreating', dict_def.name
                         )
                         client.execute(dict_def.drop_sql(database=self.database))
-                        self._query_counts[cube.__name__] += 1
+                        self._count_query(cube)
                     else:
                         continue
                 client.execute(dict_def.definition_sql(database=self.database))
-                self._query_counts[cube.__name__] += 1
+                self._count_query(cube)
 
     def _drop_dictionaries(self, cube: Type[Cube]):
         meta = self.get_table_meta(cube)
         with self.pool.get_client() as client:
             for dict_def in meta.dictionaries:
                 client.execute(dict_def.drop_sql(database=self.database))
-                self._query_counts[cube.__name__] += 1
+                self._count_query(cube)
 
     def _translate_transform(self, transform: Transform) -> (str, str):
         """
@@ -672,4 +673,9 @@ class ClickhouseCubeBackend(CubeBackend):
             client.execute(
                 f"DROP TABLE IF EXISTS {self.database}.{self.cube_to_table_name(cube)} SYNC"
             )
-            self._query_counts[cube.__name__] += 1
+            self._count_query(cube)
+
+    def _count_query(self, cube: Type[Cube]):
+        tid = threading.get_ident()
+        self._query_counts.setdefault(tid, Counter())
+        self._query_counts[tid][cube.__name__] += 1
