@@ -123,7 +123,7 @@ class DictionaryDefinition:
         db_part = f"{database}." if database else ""
         attrs = ",\n".join([attr.definition_sql() for attr in self.attrs])
         return (
-            f"CREATE DICTIONARY {db_part}{self.name} ("
+            f"CREATE DICTIONARY IF NOT EXISTS {db_part}{self.name} ("
             f"{self.key} UInt64,\n"
             f"{attrs}"
             f") "
