@@ -12,6 +12,10 @@ from hcube.api.models.filters import (
     IsNullFilter,
     ListFilter,
     NegativeListFilter,
+    Or,
+    OverlapFilter,
+    SubstringFilter,
+    SubstringMultiValueFilter,
 )
 from hcube.api.models.ordering import OrderDirection, OrderSpec
 from hcube.api.models.query import CubeQuery
@@ -116,6 +120,10 @@ class NaiveCubeBackend(CubeBackend):
 
     @classmethod
     def _row_passes_filter(cls, row, fltr: Filter) -> bool:
+        # combinators first
+        if isinstance(fltr, Or):
+            return any(cls._row_passes_filter(row, subfltr) for subfltr in fltr.filters)
+        # then plain filters
         value = getattr(row, fltr.dimension.name)
         if isinstance(fltr, ListFilter):
             return value in fltr.values
@@ -134,6 +142,18 @@ class NaiveCubeBackend(CubeBackend):
                 return value <= fltr.value
         if isinstance(fltr, EqualityFilter):
             return value == fltr.dimension.to_python(fltr.value)
+        if isinstance(fltr, SubstringFilter):
+            if fltr.case_sensitive:
+                return fltr.value in value
+            else:
+                return fltr.value.lower() in value.lower()
+        if isinstance(fltr, SubstringMultiValueFilter):
+            if fltr.case_sensitive:
+                return any(v in value for v in fltr.values)
+            else:
+                return any(v.lower() in value.lower() for v in fltr.values)
+        if isinstance(fltr, OverlapFilter):
+            return any(v in fltr.values for v in value)
         raise ValueError(f"unsupported filter {fltr}")
 
     @classmethod
