@@ -13,6 +13,7 @@ from hcube.api.models.aggregation import AggregationOp, ArrayAgg, Count
 from hcube.api.models.cube import Cube
 from hcube.api.models.dimensions import (
     ArrayDimension,
+    BooleanDimension,
     DateDimension,
     DateTimeDimension,
     Dimension,
@@ -73,6 +74,7 @@ class PostgresCubeBackend(CubeBackend):
         (FloatMetric, "Float"),
         (IntMetric, "Integer"),
         (IPDimension, "Inet"),
+        (BooleanDimension, "Boolean"),
     )
 
     def __init__(
